==> dmc-sdk-2.0.1.0-sources.jar: com/digiwin/dmc/sdk/service/download/FileService.java <==
package com.digiwin.dmc.sdk.service.download;


import com.digiwin.dmc.sdk.config.DmcUrl;
import com.digiwin.dmc.sdk.config.NetworkOptions;
import com.digiwin.dmc.sdk.config.SDKConstants;
import com.digiwin.dmc.sdk.config.ServerSetting;
import com.digiwin.dmc.sdk.exception.OperateException;
import com.digiwin.dmc.sdk.service.IUserManagerService;
import com.digiwin.dmc.sdk.service.impl.UserManagerService;
import com.digiwin.dmc.sdk.util.HttpRequestUtil;
import com.digiwin.dmc.sdk.util.StringUtil;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class FileService implements IFileService{
    private static FileService fileService;
    private static IUserManagerService userManagerService = UserManagerService.userInstance();

    private DownloadProgressEventArgs eventArgs = new DownloadProgressEventArgs();
    /**
     * 单一实例
     *
     * @return
     */
    public static IFileService fileInstance() {
        if (fileService == null) {
            fileService = new FileService();
        }
        return fileService;
    }

    @Override
    public byte[] download( String fileId) {
        return this.download(null,null,fileId,null);
    }

    @Override
    public byte[] download(String bucketName, String fileId) {
        return this.download(null,bucketName,fileId,null);
    }

    @Override
    public byte[] download(String tenantId, String bucketName, String fileId) {
        return this.download(tenantId,bucketName,fileId,null);
    }

    @Override
    public byte[]  download(String tenantId, String bucketName,String fileId,String driveToken) {
        if (StringUtil.isEmpty(bucketName)) {
            bucketName = ServerSetting.getBucketName();
        }
        String downloadDocumentUrl = DmcUrl.getFilesResourceUrl() + bucketName + "/files/" + fileId;
        Map<String, String> headers = new HashMap<>();
        if (StringUtil.isEmpty(driveToken)) {
            String userToken = userManagerService.getUserToken(ServerSetting.getUser());
            headers.put(SDKConstants.HttpHeaderUserTokenKey, userToken);
        } else {
            headers.put(SDKConstants.HttpHeaderDriveTokenKey, driveToken);
        }
        if (tenantId != null){
            headers.put(SDKConstants.HTTP_HEADER_TENANTID_KEY, tenantId);
        }
        return HttpRequestUtil.getByte(downloadDocumentUrl, headers);
    }

}

==> dmc-sdk-4.0.0.0-sources.jar: com/digiwin/dmc/sdk/service/download/FileService.java <==
package com.digiwin.dmc.sdk.service.download;


import com.digiwin.dmc.sdk.config.DmcUrl;
import com.digiwin.dmc.sdk.config.SDKConstants;
import com.digiwin.dmc.sdk.config.ServerSetting;
import com.digiwin.dmc.sdk.service.IUserManagerService;
import com.digiwin.dmc.sdk.service.impl.UserManagerService;
import com.digiwin.dmc.sdk.util.HttpRequestUtil;
import com.digiwin.dmc.sdk.util.StringUtil;

import java.util.HashMap;
import java.util.Map;

public class FileService implements IFileService {
    private static FileService fileService;
    private static IUserManagerService userManagerService = UserManagerService.userInstance();

    private DownloadProgressEventArgs eventArgs = new DownloadProgressEventArgs();

    /**
     * 单一实例
     *
     * @return
     */
    public static IFileService fileInstance() {
        if (fileService == null) {
            fileService = new FileService();
        }
        return fileService;
    }

    @Override
    public byte[] download(String fileId) {
        return this.download(null, null, fileId, null);
    }

    @Override
    public byte[] download(String bucketName, String fileId) {
        return this.download(null, bucketName, fileId, null);
    }

    @Deprecated
    @Override
    public byte[] download(String tenantId, String bucketName, String fileId) {
        return this.download(tenantId, bucketName, fileId, null);
    }

    @Deprecated
    @Override
    public byte[] download(String tenantId, String bucketName, String fileId, String driveToken) {
        if (StringUtil.isEmpty(bucketName)) {
            bucketName = ServerSetting.getBucketName();
        }
        String downloadDocumentUrl = DmcUrl.getFilesResourceUrl() + bucketName + "/files/" + fileId;
        Map<String, String> headers = new HashMap<>();
        if (StringUtil.isEmpty(driveToken)) {
            String userToken = userManagerService.getUserToken(ServerSetting.getUser());
            headers.put(SDKConstants.HttpHeaderUserTokenKey, userToken);
        } else {
            headers.put(SDKConstants.HttpHeaderDriveTokenKey, driveToken);
        }
        if (tenantId != null) {
            headers.put(SDKConstants.HTTP_HEADER_TENANTID_KEY, tenantId);
        }
        return HttpRequestUtil.getByte(downloadDocumentUrl, headers);
    }

}
